// CustomPluginImpl.cpp  


#include "stdafx.h"
#include "resource.h"
#include "TrajectoryControl.h"
#include "Mach4View.h"
#include "Engine.h"
#include "rs274ngc.h"
#include "XMLProfile.h"

#include "CustomPluginImpl.h"
#include "PluginTestDlg.h"
#include "Utility.h"
#include "dbg.h"

#include <mmsystem.h>
#include <math.h> 

HWND mach3Wnd;
CWnd mach3CWnd;

CPluginTestDlg *dlg;


// ===========================================================================
// 
// Global variables for this code 
//
// ===========================================================================

extern CMach4View *MachView;
 
//============================================================================
//
// Here are the routines which are called by Mach3
// They are the core of every plugin
//
//============================================================================

//----------------------------------------------------------------------------

// Used for destruction of variables prior to exit.
// Called as Mach3 shuts down. 

void myCleanUp()

{
	DbgMsg(("myCleanUp entry"));


	dlg->DestroyWindow();

	mach3CWnd.Detach();

	delete dlg;
	DbgMsg(("myCleanUp exit"));
}

//----------------------------------------------------------------------------

// initial access to Mach profile when enumerating available plugins
// Returns the second half on the "pluging id" for the list in Operator
// CustomPlugin adds the file name at the start of the string

CString	myProfileInit(CString name, CXMLProfile *DevProf)	

{
	DbgMsg(("myProfileInit entry"));

	//this gets the default directory DefDir in which Mach3 is located.  and the profile name ex. "Mach3Mill"
	//DefDir = DevProf->GetProfileString("Preferences","DefDir","C:\\Mach3\\");
    //Profile = DevProf->GetProfileString("Preferences","Profile","Mach3Mill");

	DbgMsg(("myProfileInit exit"));

	return(" CustomPlugin PlugIn - James W. Leonard Ver 1.0");
}

//----------------------------------------------------------------------------

// called during Mach initialisation. You can influence subsequent init by actions here
// **** Not used in typical device plugin

void myInitControl()

{
	DbgMsg(("myInitControl entry"));


	DbgMsg(("myInitControl exit"));
}

//----------------------------------------------------------------------------

void myPostInitControl()

{
	// called when mach fully set up so all data can be used but initialization  outcomes not affected

	DbgMsg(("myPostInitControl entry"));
	
	#ifndef _DEBUG

	RelMsg(("Release build CustomPlugin"));

	#endif
	
	mach3Wnd = GetMach3MainWindow();

	mach3CWnd.Attach(mach3Wnd);

	dlg = new CPluginTestDlg;

	dlg->Create(IDD_PLUGIN_TEST,&mach3CWnd);

	DbgMsg(("myPostInitControl exit"));
}

//----------------------------------------------------------------------------

// Called to configure the device
// Has read/write access to Mach XML profile to remember what it needs to.

void myConfig(CXMLProfile *DevProf)

{
	DbgMsg(("myConfig entry"));

	dlg->ShowWindow(SW_SHOW);

	DbgMsg(("myConfig exit"));
}

//----------------------------------------------------------------------------

// 10Hz update loop

void myUpdate()

{
	// DbgMsg(("myUpdate entry"));

	// DbgMsg(("myUpdate exit"));
}

//----------------------------------------------------------------------------

// called at 40Hz. This is used for Higher Res timing needs. 
// only use as required, it can use alot of system resources. 

void myHighSpeedUpdate()

{
	// DbgMsg(("myHighSpeedUpdate entry"));

	
	// DbgMsg(("myHighSpeedUpdate exit"));
}

//----------------------------------------------------------------------------

// ======================================================================================================
//
// The Helpers follow
//
//=======================================================================================================

// put your helper routines here

 